"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = format;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _chalk = _interopRequireDefault(require("chalk"));

var _settings = _interopRequireDefault(require("../settings"));

/**
 * Get formatted commit message
 * @param  {object}  input object containing structured results
 * @param  {boolean} debug show debug information in commit message
 * @return {string}        formatted debug message
 */
function format(input, debug = false) {
  const results = debug ? Object.entries(input || {}).reduce((registry, item) => {
    const _item = (0, _slicedToArray2.default)(item, 2),
          name = _item[0],
          value = _item[1]; // eslint-disable-next-line no-param-reassign


    registry[name] = value === null ? _chalk.default.grey(`<${name}>`) : _chalk.default.bold(value);
    return registry;
  }, {}) : input; // Return formatted string

  const type = results.type,
        scope = results.scope,
        subject = results.subject,
        body = results.body,
        footer = results.footer;
  const typeEnumerable = (_settings.default.type.enumerables || {})[input.type] || {};
  return [`${type}${scope ? '(' : ''}${scope}${scope ? ')' : ''}${type || scope ? ':' : ''} ${`${typeEnumerable.emoji || ''} ${subject}`}`, body, footer].filter(Boolean).join('\n');
}
//# sourceMappingURL=format.js.map