import chalk from 'chalk';

import settings from '../settings';

/**
 * Get formatted commit message
 * @param  {object}  input object containing structured results
 * @param  {boolean} debug show debug information in commit message
 * @return {string}        formatted debug message
 */
export default function format(input, debug = false) {
    const results = debug
        ? Object.entries(input || {}).reduce((registry, item) => {
            const [name, value] = item;
            // eslint-disable-next-line no-param-reassign
            registry[name] = value === null ? chalk.grey(`<${name}>`) : chalk.bold(value);
            return registry;
        }, {})
        : input;

    // Return formatted string
    const { type, scope, subject, body, footer } = results;
    const typeEnumerable = (settings.type.enumerables || {})[input.type] || {};

    return [
        `${type}${scope ? '(' : ''}${scope}${scope ? ')' : ''}${
            type || scope ? ':' : ''
        } ${`${typeEnumerable.emoji || ''} ${subject}`}`,
        body,
        footer,
    ]
        .filter(Boolean)
        .join('\n');
}
